import React, { useState, useEffect } from 'react';
import { Search, Globe2, ArrowRight, ChevronRight, Star, Tag, Plus, X, Cookie, FileText, Zap, BarChart, Smartphone, Gauge, Layout, Link2 } from 'lucide-react';
import { analyzeSEO } from './utils/seoAnalyzer';
import SEOResults from './components/SEOResults';
import AboutUs from './pages/AboutUs';
import Contact from './pages/Contact';
import PrivacyPolicy from './pages/PrivacyPolicy';
import TermsOfService from './pages/TermsOfService';

function App() {
  const [url, setUrl] = useState('');
  const [currentPage, setCurrentPage] = useState('home');
  const [isAnalyzing, setIsAnalyzing] = useState(false);
  const [results, setResults] = useState(null);
  const [includeKeywords, setIncludeKeywords] = useState(false);
  const [customKeywords, setCustomKeywords] = useState(['']);
  const [showKeywordInput, setShowKeywordInput] = useState(false);
  const [showCookieConsent, setShowCookieConsent] = useState(true);
  const [error, setError] = useState('');
  const [cookiePreferences, setCookiePreferences] = useState({
    necessary: true,
    analytics: false,
    marketing: false
  });

  useEffect(() => {
    const consent = localStorage.getItem('cookieConsent');
    if (consent) {
      setShowCookieConsent(false);
      setCookiePreferences(JSON.parse(consent));
    }
  }, []);

  // Single AdSense initialization
  useEffect(() => {
    const initAds = () => {
      try {
        if (typeof window !== 'undefined' && window.adsbygoogle) {
          const adElements = document.querySelectorAll('.adsbygoogle');
          adElements.forEach(ad => {
            if (!ad.hasAttribute('data-adsbygoogle-initialized')) {
              (window.adsbygoogle = window.adsbygoogle || []).push({});
              ad.setAttribute('data-adsbygoogle-initialized', 'true');
            }
          });
        }
      } catch (err) {
        console.error('AdSense initialization error:', err);
      }
    };

    // Initialize ads when page changes
    const timer = setTimeout(initAds, 100);
    return () => clearTimeout(timer);
  }, [currentPage]);

  const handleCookieConsent = (acceptAll = false) => {
    const preferences = acceptAll 
      ? { necessary: true, analytics: true, marketing: true }
      : cookiePreferences;
    
    localStorage.setItem('cookieConsent', JSON.stringify(preferences));
    setShowCookieConsent(false);
    setCookiePreferences(preferences);
  };

  const handleAddKeyword = () => {
    setCustomKeywords([...customKeywords, '']);
  };

  const handleRemoveKeyword = (index) => {
    const newKeywords = customKeywords.filter((_, i) => i !== index);
    setCustomKeywords(newKeywords.length ? newKeywords : ['']);
  };

  const handleKeywordChange = (index, value) => {
    const newKeywords = [...customKeywords];
    newKeywords[index] = value;
    setCustomKeywords(newKeywords);
  };

  const handleAnalyze = async () => {
    if (!url) {
      setError('Please enter a URL to analyze');
      return;
    }

    try {
      const urlObj = new URL(url);
      setError('');
      setIsAnalyzing(true);
      
      const keywords = includeKeywords ? customKeywords.filter(k => k.trim()) : [];
      const analysisResults = await analyzeSEO(url, includeKeywords, keywords);
      setResults(analysisResults);
    } catch (error) {
      if (error instanceof Error) {
        setError(error.message.includes('URL') ? 'Please enter a valid URL (e.g., https://example.com)' : 'Failed to analyze the website. Please try again.');
      } else {
        setError('An unexpected error occurred. Please try again.');
      }
      setResults(null);
    } finally {
      setIsAnalyzing(false);
    }
  };

  function renderPage() {
    switch (currentPage) {
      case 'about':
        return <AboutUs />;
      case 'contact':
        return <Contact />;
      case 'privacy':
        return <PrivacyPolicy />;
      case 'terms':
        return <TermsOfService />;
      default:
        return (
          <>
            {/* Hero Section */}
            <div className="container mx-auto px-4 py-16">
              <div className="text-center max-w-4xl mx-auto">
                <h1 className="text-5xl font-bold text-gray-900 mb-6">
                  Comprehensive Website SEO Analysis & Optimization
                </h1>
                <p className="text-xl text-gray-600 mb-8">
                  Unlock your website's full potential with our advanced SEO analysis tool. Get detailed insights into your site's performance, discover optimization opportunities, and outrank your competitors with actionable recommendations.
                </p>
                
                {/* Search Box */}
                <div className="bg-white rounded-lg shadow-xl p-6 max-w-2xl mx-auto mb-12">
                  <div className="flex flex-col gap-4">
                    <div className="flex items-center bg-gray-50 rounded-md px-4">
                      <Globe2 className="text-gray-400 w-5 h-5" />
                      <input
                        type="text"
                        placeholder="Enter website URL to analyze (e.g., https://example.com)"
                        className="w-full p-3 bg-transparent border-none focus:outline-none text-gray-800"
                        value={url}
                        onChange={(e) => setUrl(e.target.value)}
                      />
                    </div>

                    {error && (
                      <div className="text-red-600 text-sm text-left px-4">
                        {error}
                      </div>
                    )}

                    <div className="flex items-center justify-between px-4">
                      <label className="flex items-center gap-2 text-gray-600">
                        <input
                          type="checkbox"
                          checked={includeKeywords}
                          onChange={(e) => {
                            setIncludeKeywords(e.target.checked);
                            if (e.target.checked) {
                              setShowKeywordInput(true);
                            } else {
                              setShowKeywordInput(false);
                              setCustomKeywords(['']);
                            }
                          }}
                          className="rounded text-blue-600"
                        />
                        <div className="flex items-center gap-2">
                          <Tag className="w-4 h-4" />
                          Include keyword analysis
                        </div>
                      </label>
                    </div>

                    {showKeywordInput && (
                      <div className="space-y-3 px-4">
                        <div className="flex items-center justify-between">
                          <h3 className="text-sm font-medium text-gray-700">Custom Keywords</h3>
                          <button
                            onClick={handleAddKeyword}
                            className="text-blue-600 hover:text-blue-700 flex items-center gap-1 text-sm"
                          >
                            <Plus className="w-4 h-4" />
                            Add Keyword
                          </button>
                        </div>
                        {customKeywords.map((keyword, index) => (
                          <div key={index} className="flex items-center gap-2">
                            <input
                              type="text"
                              value={keyword}
                              onChange={(e) => handleKeywordChange(index, e.target.value)}
                              placeholder="Enter keyword"
                              className="flex-1 p-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                            />
                            {customKeywords.length > 1 && (
                              <button
                                onClick={() => handleRemoveKeyword(index)}
                                className="text-red-500 hover:text-red-600"
                              >
                                <X className="w-4 h-4" />
                              </button>
                            )}
                          </div>
                        ))}
                      </div>
                    )}

                    <div className="flex justify-center">
                      <button
                        className={`bg-blue-600 hover:bg-blue-700 text-white px-8 py-3 rounded-md flex items-center gap-2 transition-colors ${isAnalyzing ? 'opacity-75 cursor-not-allowed' : ''}`}
                        onClick={handleAnalyze}
                        disabled={isAnalyzing}
                      >
                        {isAnalyzing ? 'Analyzing...' : 'Analyze Your Website'}
                        <ArrowRight className="w-4 h-4" />
                      </button>
                    </div>
                  </div>
                </div>

                {/* Results Section */}
                {results && (
                  <div className="mb-16">
                    <SEOResults results={results} />
                  </div>
                )}

                {/* Key Features Grid */}
                <div className="grid md:grid-cols-3 gap-8 mb-16">
                  {[
                    {
                      icon: <Gauge className="w-12 h-12 text-blue-600" />,
                      title: "Performance Analysis",
                      description: "Get detailed insights into your website's loading speed, Core Web Vitals, and performance metrics across all devices."
                    },
                    {
                      icon: <Layout className="w-12 h-12 text-blue-600" />,
                      title: "Technical SEO Audit",
                      description: "Comprehensive analysis of meta tags, headings, content structure, and other crucial technical SEO elements."
                    },
                    {
                      icon: <Link2 className="w-12 h-12 text-blue-600" />,
                      title: "Backlink Analysis",
                      description: "Evaluate your website's link profile, identify toxic links, and discover new link-building opportunities."
                    },
                    {
                      icon: <Smartphone className="w-12 h-12 text-blue-600" />,
                      title: "Mobile Optimization",
                      description: "Ensure your website provides an excellent experience across all mobile devices and screen sizes."
                    },
                    {
                      icon: <BarChart className="w-12 h-12 text-blue-600" />,
                      title: "Competitor Analysis",
                      description: "Compare your website's performance against competitors and identify areas for improvement."
                    },
                    {
                      icon: <Zap className="w-12 h-12 text-blue-600" />,
                      title: "Actionable Insights",
                      description: "Receive prioritized recommendations to improve your website's search engine rankings and visibility."
                    }
                  ].map((feature, index) => (
                    <div key={index} className="bg-white p-6 rounded-lg shadow-lg">
                      <div className="flex justify-center mb-4">{feature.icon}</div>
                      <h3 className="text-xl font-semibold mb-3 text-center">{feature.title}</h3>
                      <p className="text-gray-600 text-center">{feature.description}</p>
                    </div>
                  ))}
                </div>
              </div>
            </div>

            {/* How It Works Section */}
            <div className="bg-white py-16">
              <div className="container mx-auto px-4">
                <h2 className="text-3xl font-bold text-center text-gray-900 mb-12">
                  How Our SEO Analysis Works
                </h2>
                <div className="grid md:grid-cols-4 gap-8">
                  {[
                    { 
                      number: '1',
                      title: 'Enter Your URL',
                      description: 'Simply enter your website URL to begin the comprehensive SEO analysis'
                    },
                    {
                      number: '2',
                      title: 'Deep Analysis',
                      description: 'Our advanced algorithms analyze over 100+ SEO factors and technical elements'
                    },
                    {
                      number: '3',
                      title: 'Get Insights',
                      description: 'Receive detailed reports with actionable recommendations and priorities'
                    },
                    {
                      number: '4',
                      title: 'Optimize & Improve',
                      description: "Implement suggestions to enhance your website's search engine rankings"
                    }
                  ].map((step, index) => (
                    <div key={index} className="text-center">
                      <div className="text-4xl font-bold text-blue-600 mb-4">{step.number}</div>
                      <h3 className="text-xl font-semibold mb-2">{step.title}</h3>
                      <p className="text-gray-600">{step.description}</p>
                    </div>
                  ))}
                </div>
              </div>
            </div>

            {/* Testimonials Section */}
            <div className="container mx-auto px-4 py-16">
              <h2 className="text-3xl font-bold text-center text-gray-900 mb-12">
                Trusted by Digital Marketers & SEO Professionals
              </h2>
              <div className="grid md:grid-cols-3 gap-8">
                {[
                  {
                    name: 'Sarah Johnson',
                    role: 'Digital Marketing Director',
                    content: "This SEO analysis tool has transformed how we optimize our clients' websites. The detailed insights and actionable recommendations have helped us achieve significant ranking improvements.",
                  },
                  {
                    name: 'Mike Chen',
                    role: 'E-commerce Owner',
                    content: "The comprehensive analysis helped us identify and fix critical SEO issues we weren't aware of. Our organic traffic has increased by 150% since implementing the recommendations.",
                  },
                  {
                    name: 'Emily Brown',
                    role: 'SEO Consultant',
                    content: "As an SEO professional, I appreciate the depth of analysis and technical insights provided. It's become an essential tool in my optimization workflow.",
                  },
                ].map((testimonial, index) => (
                  <div key={index} className="bg-white rounded-xl p-6 shadow-lg">
                    <div className="flex items-center mb-4">
                      {[...Array(5)].map((_, i) => (
                        <Star key={i} className="w-5 h-5 text-yellow-400 fill-current" />
                      ))}
                    </div>
                    <p className="text-gray-600 mb-4">{testimonial.content}</p>
                    <div>
                      <p className="font-semibold text-gray-900">{testimonial.name}</p>
                      <p className="text-gray-500 text-sm">{testimonial.role}</p>
                    </div>
                  </div>
                ))}
              </div>
            </div>

            {/* CTA Section */}
            <div className="bg-blue-600 text-white py-16">
              <div className="container mx-auto px-4 text-center">
                <h2 className="text-3xl font-bold mb-4">
                  Start Optimizing Your Website Today
                </h2>
                <p className="text-xl mb-8 opacity-90">
                  Join thousands of successful websites that have improved their search rankings with our comprehensive SEO analysis tool
                </p>
                <button
                  className="bg-white text-blue-600 px-8 py-3 rounded-md font-semibold hover:bg-gray-100 transition-colors inline-flex items-center gap-2"
                  onClick={() => window.scrollTo({ top: 0, behavior: 'smooth' })}
                >
                  Analyze Your Website
                  <ChevronRight className="w-4 h-4" />
                </button>
              </div>
            </div>
          </>
        );
    }
  }

  return (
    <div className="min-h-screen bg-gradient-to-b from-blue-50 to-white">
      {/* Navigation */}
      <nav className="bg-white shadow-sm">
        <div className="container mx-auto px-4">
          <div className="flex items-center justify-between h-16">
            <button
              onClick={() => setCurrentPage('home')}
              className="text-xl font-bold text-gray-900 hover:text-blue-600 transition-colors"
            >
              SEO Checker
            </button>
            <div className="flex gap-6">
              <button
                onClick={() => setCurrentPage('home')}
                className="text-gray-600 hover:text-blue-600 transition-colors"
              >
                Home
              </button>
              <button
                onClick={() => setCurrentPage('about')}
                className="text-gray-600 hover:text-blue-600 transition-colors"
              >
                About
              </button>
              <button
                onClick={() => setCurrentPage('contact')}
                className="text-gray-600 hover:text-blue-600 transition-colors"
              >
                Contact
              </button>
            </div>
          </div>
        </div>
      </nav>

      {/* Main Content */}
      {renderPage()}

      {/* Cookie Consent Banner */}
      {showCookieConsent && (
        <div className="fixed bottom-0 left-0 right-0 bg-white shadow-lg border-t border-gray-200 p-4 z-50">
          <div className="container mx-auto max-w-6xl">
            <div className="flex flex-col md:flex-row items-start md:items-center justify-between gap-4">
              <div className="flex items-start gap-3">
                <Cookie className="w-6 h-6 text-blue-600 flex-shrink-0 mt-1" />
                <div>
                  <h3 className="text-lg font-semibold mb-2">Cookie Preferences</h3>
                  <p className="text-gray-600 text-sm mb-3">
                    We use cookies to enhance your experience. Choose your cookie preferences below.
                  </p>
                  <div className="space-y-2">
                    <label className="flex items-center gap-2">
                      <input
                        type="checkbox"
                        checked={cookiePreferences.necessary}
                        disabled
                        className="rounded text-blue-600"
                      />
                      <span className="text-sm">Necessary (Required)</span>
                    </label>
                    <label className="flex items-center gap-2">
                      <input
                        type="checkbox"
                        checked={cookiePreferences.analytics}
                        onChange={(e) => setCookiePreferences({
                          ...cookiePreferences,
                          analytics: e.target.checked
                        })}
                        className="rounded text-blue-600"
                      />
                      <span className="text-sm">Analytics</span>
                    </label>
                    <label className="flex items-center gap-2">
                      <input
                        type="checkbox"
                        checked={cookiePreferences.marketing}
                        onChange={(e) => setCookiePreferences({
                          ...cookiePreferences,
                          marketing: e.target.checked
                        })}
                        className="rounded text-blue-600"
                      />
                      <span className="text-sm">Marketing</span>
                    </label>
                  </div>
                </div>
              </div>
              <div className="flex flex-col sm:flex-row gap-3 w-full md:w-auto">
                <button
                  onClick={() => handleCookieConsent(true)}
                  className="bg-blue-600 text-white px-6 py-2 rounded-md hover:bg-blue-700 transition-colors text-sm"
                >
                  Accept All
                </button>
                <button
                  onClick={() => handleCookieConsent(false)}
                  className="border border-gray-300 px-6 py-2 rounded-md hover:bg-gray-50 transition-colors text-sm"
                >
                  Save Preferences
                </button>
              </div>
            </div>
          </div>
        </div>
      )}

      {/* Footer */}
      <footer className="bg-gray-900 text-white py-12">
        <div className="container mx-auto px-4">
          <div className="grid md:grid-cols-3 gap-8">
            <div>
              <h3 className="text-xl font-bold mb-4">SEO Checker</h3>
              <p className="text-gray-400">
                Free website SEO analysis and audit tool
              </p>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-4">Company</h3>
              <ul className="space-y-2">
                {[
                  { text: 'About', page: 'about' },
                  { text: 'Contact', page: 'contact' },
                  { text: 'Privacy Policy', page: 'privacy' },
                  { text: 'Terms of Service', page: 'terms' },
                ].map((link, i) => (
                  <li key={i}>
                    <button
                      onClick={() => setCurrentPage(link.page)}
                      className="text-gray-400 hover:text-white transition-colors"
                    >
                      {link.text}
                    </button>
                  </li>
                ))}
              </ul>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-4">Resources</h3>
              <ul className="space-y-2">
                <li>
                  <a
                    href="/sitemap.xml"
                    target="_blank"
                    rel="noopener noreferrer"
                    className="text-gray-400 hover:text-white transition-colors flex items-center gap-2"
                  >
                    <FileText className="w-4 h-4" />
                    Sitemap
                  </a>
                </li>
              </ul>
            </div>
          </div>
          <div className="border-t border-gray-800 mt-12 pt-8 text-center text-gray-400">
            <p>© {new Date().getFullYear()} SEO Checker. All rights reserved.</p>
          </div>
        </div>
      </footer>
    </div>
  );
}

export default App;